package com.ruoyi.system.controller;

import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.PathVariable;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.bind.annotation.GetMapping;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import java.util.List;
import com.ruoyi.common.core.web.page.TableDataInfo;
import org.springframework.web.bind.annotation.PostMapping;
import com.ruoyi.common.core.web.domain.AjaxResult;
import org.springframework.web.bind.annotation.RequestBody;
import com.ruoyi.system.domain.SnServerTask;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.service.ISnServerTaskService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.core.web.controller.BaseController;

@RestController
@RequestMapping({ "/SnServerTask" })
public class SnServerTaskController extends BaseController
{
    @Autowired
    private ISnServerTaskService snServerTaskService;
    
    @PostMapping({ "/queryStatus" })
    public AjaxResult queryStatus(@RequestBody final SnServerTask snServerTask) {
        return this.snServerTaskService.queryLastStatus(snServerTask);
    }
    
    @RequiresPermissions({ "system:SnServerTask:list" })
    @GetMapping({ "/list" })
    public TableDataInfo list(final SnServerTask snServerTask) {
        this.startPage();
        final List<SnServerTask> list = this.snServerTaskService.selectSnServerTaskList(snServerTask);
        return this.getDataTable((List)list);
    }
    
    @RequiresPermissions({ "system:SnServerTask:export" })
    @Log(title = "服务器任务", businessType = BusinessType.EXPORT)
    @PostMapping({ "/export" })
    public void export(final HttpServletResponse response, final SnServerTask snServerTask) {
        final List<SnServerTask> list = this.snServerTaskService.selectSnServerTaskList(snServerTask);
        final ExcelUtil<SnServerTask> util = (ExcelUtil<SnServerTask>)new ExcelUtil((Class)SnServerTask.class);
        util.exportExcel(response, (List)list, "服务器任务数据");
    }
    
    @RequiresPermissions({ "system:SnServerTask:query" })
    @GetMapping({ "/{taskId}" })
    public AjaxResult getInfo(@PathVariable("taskId") final Long taskId) {
        return this.success((Object)this.snServerTaskService.selectSnServerTaskByTaskId(taskId));
    }
    
    @RequiresPermissions({ "system:SnServerTask:add" })
    @Log(title = "新增服务器任务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody final SnServerTask snServerTask) {
        return this.snServerTaskService.insertSnServerTask(snServerTask);
    }
    
    @RequiresPermissions({ "system:SnServerTask:edit" })
    @Log(title = "服务器任务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody final SnServerTask snServerTask) {
        return this.toAjax(this.snServerTaskService.updateSnServerTask(snServerTask));
    }
    
    @RequiresPermissions({ "system:SnServerTask:remove" })
    @Log(title = "服务器任务", businessType = BusinessType.DELETE)
    @DeleteMapping({ "/{taskIds}" })
    public AjaxResult remove(@PathVariable final Long[] taskIds) {
        return this.toAjax(this.snServerTaskService.deleteSnServerTaskByTaskIds(taskIds));
    }
}
